Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLev Dragunov <l.dragunov@corp.mail.ru>2015-10-27 13:10:25 +0300
committerLev Dragunov <l.dragunov@corp.mail.ru>2015-10-27 13:49:37 +0300
commit5fb248fc148ab382d4adc0df135821c44920ae82 (patch)
treeea8ab6273155eadca1c274d38780d9475f2b240b /routing/routing_session.hpp
parentacfe9b010b955425997a412e91e86a1e3774e736 (diff)
Spelling fixes
Diffstat (limited to 'routing/routing_session.hpp')
-rw-r--r--routing/routing_session.hpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/routing/routing_session.hpp b/routing/routing_session.hpp
index 0c1e8c4a15..a8e5c971e3 100644
--- a/routing/routing_session.hpp
+++ b/routing/routing_session.hpp
@@ -45,7 +45,7 @@ public:
OnRoute, // user follows the route
RouteNeedRebuild, // user left the route
RouteFinished, // destination point is reached but the session isn't closed
- RouteNoFollow // route is builded but following mode were disabled
+ RouteNoFollowing // route is built but following mode has been disabled
};
/*
@@ -55,7 +55,7 @@ public:
* RouteNotStarted -> OnRoute // user started following the route
* RouteNotStarted -> RouteNeedRebuild // user doesn't like the route.
* OnRoute -> RouteNeedRebuild // user moves away from route - need to rebuild
* OnRoute -> RouteNoFollow // following mode was disabled. Router don't track position.
* OnRoute -> RouteFinished // user reached the end of route
* RouteNeedRebuild -> RouteNotReady // start rebuild route
* RouteFinished -> RouteNotReady // start new route
@@ -100,9 +100,9 @@ public:
void ActivateAdditionalFeatures() {}
- /// Disable following mode on GPS updates. Following mode disables only for the current route.
- /// If routed will be rebuilt you must call DisableFollowMode again.
- /// Returns truw if following were disabled, false if route not ready yet.
+ /// Disable following mode on GPS updates. Following mode is disabled only for the current route.
+ /// If a route is rebuilt you must call DisableFollowMode again.
+ /// Returns true if following was disabled, false if a route is not ready for the following yet.
bool DisableFollowMode();
void SetRoutingSettings(RoutingSettings const & routingSettings);
@@ -55,7 +55,7 @@ public:
* RouteNotStarted -> RouteNeedRebuild // user doesn't like the route.
* OnRoute -> RouteNeedRebuild // user moves away from route - need to rebuild
- * OnRoute -> RouteNoFollow // following mode was disabled. Router don't track position.
+ * OnRoute -> RouteNoFollowing // following mode was disabled. Router doesn't track position.
* OnRoute -> RouteFinished // user reached the end of route
* RouteNeedRebuild -> RouteNotReady // start rebuild route